@@ -6,9 +6,11 @@ from copy import copy
 from django.conf import settings
 from django.contrib.contenttypes.generic import GenericRelation
 from django.core.exceptions import ImproperlyConfigured
-from django.db.models import get_model, IntegerField, CharField, FloatField
+from django.db.models import IntegerField, CharField, FloatField
 from django.db.models.signals import post_save, post_delete
 
+from mezzanine.utils.models import lazy_model_ops
+
 
 class BaseGenericRelation(GenericRelation):
     """
@@ -88,13 +90,15 @@ class BaseGenericRelation(GenericRelation):
             # the field/manager by name.
             getter_name = "get_%s_name" % self.__class__.__name__.lower()
             cls.add_to_class(getter_name, lambda self: name)
-            # For some unknown reason the signal won't be triggered
-            # if given a sender arg, particularly when running
-            # Cartridge with the field RichTextPage.keywords - so
-            # instead of specifying self.rel.to as the sender, we
-            # check for it inside the signal itself.
-            post_save.connect(self._related_items_changed)
-            post_delete.connect(self._related_items_changed)
+
+            def connect_save(sender):
+                post_save.connect(self._related_items_changed, sender=sender)
+
+            def connect_delete(sender):
+                post_delete.connect(self._related_items_changed, sender=sender)
+
+            lazy_model_ops.add(connect_save, self.rel.to)
+            lazy_model_ops.add(connect_delete, self.rel.to)
 
     def _related_items_changed(self, **kwargs):
         """
@@ -102,16 +106,6 @@ class BaseGenericRelation(GenericRelation):
         this field applies to, and pass the instance to the real
         ``related_items_changed`` handler.
         """
-        # Manually check that the instance matches the relation,
-        # since we don't specify a sender for the signal.
-        try:
-            to = self.rel.to
-            if isinstance(to, str):
-                to = get_model(*to.split(".", 1))
-            if not isinstance(kwargs["instance"], to):
-                raise TypeError
-        except (TypeError, ValueError):
-            return
         for_model = kwargs["instance"].content_type.model_class()
         if issubclass(for_model, self.model):
             instance_id = kwargs["instance"].object_pk
