@@ -3,6 +3,7 @@ from __future__ import print_function, unicode_literals
 from optparse import make_option
 
 from django.core.management.base import NoArgsCommand
+from django import db
 
 from mezzanine.twitter.models import Query, TwitterQueryException
 
@@ -25,3 +26,7 @@ class Command(NoArgsCommand):
                 query.run()
             except TwitterQueryException as e:
                 print("Twitter query error [%s]: %s" % (query, e))
+        try:
+            db.close_connection()
+        except:
+            pass
